# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLevelSetsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkShapePriorSegmentationLevelSetImageFilterPython
else:
    import _itkShapePriorSegmentationLevelSetImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKFastMarchingBasePython
import itk.itkFastMarchingStoppingCriterionBasePython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkNodePairPython
import itk.itkLevelSetNodePython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.ITKOptimizersBasePython
import itk.ITKCostFunctionsPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkArray2DPython
import itk.itkCostFunctionPython
import itk.vnl_least_squares_functionPython
import itk.itkShapeSignedDistanceFunctionPython
import itk.itkSpatialFunctionPython
import itk.itkFunctionBasePython
import itk.itkContinuousIndexPython
import itk.itkSegmentationLevelSetImageFilterPython
import itk.itkSparseFieldLevelSetImageFilterPython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkFiniteDifferenceFunctionPython
import itk.itkSegmentationLevelSetFunctionPython
import itk.itkLevelSetFunctionPython
import itk.itkShapePriorMAPCostFunctionBasePython
class itkShapePriorSegmentationLevelSetImageFilterIF2IF2F(itk.itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF2IF2F):
    r"""Proxy of C++ itkShapePriorSegmentationLevelSetImageFilterIF2IF2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetShapeFunction(self, s):
        r"""
        SetShapeFunction(self, s)

        Parameters
        ----------
        s: itkShapeSignedDistanceFunctionD2 *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_SetShapeFunction(self, s)

    def GetModifiableShapeFunction(self):
        r"""GetModifiableShapeFunction(self) -> itkShapeSignedDistanceFunctionD2"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetModifiableShapeFunction(self)

    def GetShapeFunction(self, *args):
        r"""
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD2
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD2
        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetShapeFunction(self, *args)

    def SetCostFunction(self, _arg):
        r"""
        SetCostFunction(self, _arg)

        Parameters
        ----------
        _arg: itkShapePriorMAPCostFunctionBaseIF2F *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_SetCostFunction(self, _arg)

    def GetModifiableCostFunction(self):
        r"""GetModifiableCostFunction(self) -> itkShapePriorMAPCostFunctionBaseIF2F"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetModifiableCostFunction(self)

    def GetCostFunction(self, *args):
        r"""
        GetCostFunction(self) -> itkShapePriorMAPCostFunctionBaseIF2F
        GetCostFunction(self) -> itkShapePriorMAPCostFunctionBaseIF2F
        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetCostFunction(self, *args)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetOptimizer(self, *args)

    def SetInitialParameters(self, _arg):
        r"""
        SetInitialParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_SetInitialParameters(self, _arg)

    def GetInitialParameters(self):
        r"""GetInitialParameters(self) -> itkOptimizerParametersD"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetInitialParameters(self)

    def SetShapePriorScaling(self, v):
        r"""
        SetShapePriorScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_SetShapePriorScaling(self, v)

    def GetShapePriorScaling(self):
        r"""GetShapePriorScaling(self) -> float"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetShapePriorScaling(self)

    def SetShapePriorSegmentationFunction(self, s):
        r"""
        SetShapePriorSegmentationFunction(self, s)

        Parameters
        ----------
        s: itk::ShapePriorSegmentationLevelSetFunction< itk::Image< float > > *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_SetShapePriorSegmentationFunction(self, s)

    def GetShapePriorSegmentationFunction(self):
        r"""GetShapePriorSegmentationFunction(self) -> itk::ShapePriorSegmentationLevelSetFunction< itk::Image< float > > *"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetShapePriorSegmentationFunction(self)

    def GetCurrentParameters(self):
        r"""GetCurrentParameters(self) -> itkOptimizerParametersD"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_GetCurrentParameters(self)
    __swig_destroy__ = _itkShapePriorSegmentationLevelSetImageFilterPython.delete_itkShapePriorSegmentationLevelSetImageFilterIF2IF2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapePriorSegmentationLevelSetImageFilterIF2IF2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_cast(obj)

# Register itkShapePriorSegmentationLevelSetImageFilterIF2IF2F in _itkShapePriorSegmentationLevelSetImageFilterPython:
_itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF2IF2F_swigregister(itkShapePriorSegmentationLevelSetImageFilterIF2IF2F)
class itkShapePriorSegmentationLevelSetImageFilterIF3IF3F(itk.itkSegmentationLevelSetImageFilterPython.itkSegmentationLevelSetImageFilterIF3IF3F):
    r"""Proxy of C++ itkShapePriorSegmentationLevelSetImageFilterIF3IF3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def SetShapeFunction(self, s):
        r"""
        SetShapeFunction(self, s)

        Parameters
        ----------
        s: itkShapeSignedDistanceFunctionD3 *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_SetShapeFunction(self, s)

    def GetModifiableShapeFunction(self):
        r"""GetModifiableShapeFunction(self) -> itkShapeSignedDistanceFunctionD3"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetModifiableShapeFunction(self)

    def GetShapeFunction(self, *args):
        r"""
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD3
        GetShapeFunction(self) -> itkShapeSignedDistanceFunctionD3
        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetShapeFunction(self, *args)

    def SetCostFunction(self, _arg):
        r"""
        SetCostFunction(self, _arg)

        Parameters
        ----------
        _arg: itkShapePriorMAPCostFunctionBaseIF3F *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_SetCostFunction(self, _arg)

    def GetModifiableCostFunction(self):
        r"""GetModifiableCostFunction(self) -> itkShapePriorMAPCostFunctionBaseIF3F"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetModifiableCostFunction(self)

    def GetCostFunction(self, *args):
        r"""
        GetCostFunction(self) -> itkShapePriorMAPCostFunctionBaseIF3F
        GetCostFunction(self) -> itkShapePriorMAPCostFunctionBaseIF3F
        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetCostFunction(self, *args)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetOptimizer(self, *args)

    def SetInitialParameters(self, _arg):
        r"""
        SetInitialParameters(self, _arg)

        Parameters
        ----------
        _arg: itkOptimizerParametersD

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_SetInitialParameters(self, _arg)

    def GetInitialParameters(self):
        r"""GetInitialParameters(self) -> itkOptimizerParametersD"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetInitialParameters(self)

    def SetShapePriorScaling(self, v):
        r"""
        SetShapePriorScaling(self, v)

        Parameters
        ----------
        v: float

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_SetShapePriorScaling(self, v)

    def GetShapePriorScaling(self):
        r"""GetShapePriorScaling(self) -> float"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetShapePriorScaling(self)

    def SetShapePriorSegmentationFunction(self, s):
        r"""
        SetShapePriorSegmentationFunction(self, s)

        Parameters
        ----------
        s: itk::ShapePriorSegmentationLevelSetFunction< itk::Image< float,3 > > *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_SetShapePriorSegmentationFunction(self, s)

    def GetShapePriorSegmentationFunction(self):
        r"""GetShapePriorSegmentationFunction(self) -> itk::ShapePriorSegmentationLevelSetFunction< itk::Image< float,3 > > *"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetShapePriorSegmentationFunction(self)

    def GetCurrentParameters(self):
        r"""GetCurrentParameters(self) -> itkOptimizerParametersD"""
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_GetCurrentParameters(self)
    __swig_destroy__ = _itkShapePriorSegmentationLevelSetImageFilterPython.delete_itkShapePriorSegmentationLevelSetImageFilterIF3IF3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapePriorSegmentationLevelSetImageFilterIF3IF3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_cast(obj)

# Register itkShapePriorSegmentationLevelSetImageFilterIF3IF3F in _itkShapePriorSegmentationLevelSetImageFilterPython:
_itkShapePriorSegmentationLevelSetImageFilterPython.itkShapePriorSegmentationLevelSetImageFilterIF3IF3F_swigregister(itkShapePriorSegmentationLevelSetImageFilterIF3IF3F)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def shape_prior_segmentation_level_set_image_filter(*args: itkt.ImageLike,  shape_function=..., cost_function=..., optimizer=..., initial_parameters=..., shape_prior_scaling: float=..., shape_prior_segmentation_function=..., maximum_iterations: int=..., feature_image: itkt.Image=..., initial_image: itkt.Image=..., speed_image: itkt.Image=..., advection_image: itkt.Image=..., use_negative_features: bool=..., reverse_expansion_direction: bool=..., auto_generate_speed_advection: bool=..., feature_scaling: float=..., propagation_scaling: float=..., advection_scaling: float=..., curvature_scaling: float=..., use_minimal_curvature: bool=..., segmentation_function=..., maximum_curvature_time_step: float=..., maximum_propagation_time_step: float=..., number_of_layers: int=..., iso_surface_value: float=..., interpolate_surface_location: bool=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ShapePriorSegmentationLevelSetImageFilter"""
    import itk

    kwarg_typehints = { 'shape_function':shape_function,'cost_function':cost_function,'optimizer':optimizer,'initial_parameters':initial_parameters,'shape_prior_scaling':shape_prior_scaling,'shape_prior_segmentation_function':shape_prior_segmentation_function,'maximum_iterations':maximum_iterations,'feature_image':feature_image,'initial_image':initial_image,'speed_image':speed_image,'advection_image':advection_image,'use_negative_features':use_negative_features,'reverse_expansion_direction':reverse_expansion_direction,'auto_generate_speed_advection':auto_generate_speed_advection,'feature_scaling':feature_scaling,'propagation_scaling':propagation_scaling,'advection_scaling':advection_scaling,'curvature_scaling':curvature_scaling,'use_minimal_curvature':use_minimal_curvature,'segmentation_function':segmentation_function,'maximum_curvature_time_step':maximum_curvature_time_step,'maximum_propagation_time_step':maximum_propagation_time_step,'number_of_layers':number_of_layers,'iso_surface_value':iso_surface_value,'interpolate_surface_location':interpolate_surface_location,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ShapePriorSegmentationLevelSetImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def shape_prior_segmentation_level_set_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLevelSets.ShapePriorSegmentationLevelSetImageFilter
    shape_prior_segmentation_level_set_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    shape_prior_segmentation_level_set_image_filter.__doc__ = filter_object.__doc__



